@@ -1,7 +1,8 @@
 ## File Name: fit_yjt_scaled.R
-## File Version: 0.11
+## File Version: 0.13
 
-fit_yjt_scaled <- function(x, df=Inf, par_init=NULL, lambda_fixed=NULL, weights=NULL, probit=FALSE)
+fit_yjt_scaled <- function(x, df=Inf, par_init=NULL, lambda_fixed=NULL,
+                    weights=NULL, probit=FALSE)
 {
     CALL <- match.call()
     res <- fit_mdmb_distribution(x=x, type="yjt_scaled", df=df, par_init=par_init,
