@@ -1,5 +1,5 @@
 ## File Name: frm_define_model_R_function.R
-## File Version: 0.688
+## File Version: 0.692
 
 frm_define_model_R_function <- function(model, use_grad=2, use_gibbs=FALSE,
     R_args=NULL, sampling_level=NULL, variable_level=NULL, maxiter=8, dat0=NULL )
@@ -36,7 +36,8 @@ frm_define_model_R_function <- function(model, use_grad=2, use_gibbs=FALSE,
         R_args$use_grad <- use_grad
         R_density_fct <- "frm_logistic_density"
         R_args$probit <- NULL
-        R_args <- frm_define_model_R_function_include_maxiter(R_args=R_args, maxiter=maxiter)
+        R_args <- frm_define_model_R_function_include_maxiter(R_args=R_args,
+                            maxiter=maxiter)
     }
     #--- ordinal probit regression
     if (model$model=="oprobit"){
@@ -45,7 +46,8 @@ frm_define_model_R_function <- function(model, use_grad=2, use_gibbs=FALSE,
         R_args$use_grad <- use_grad
         R_density_fct <- "frm_oprobit_density"
         R_args$probit <- NULL
-        R_args <- frm_define_model_R_function_include_maxiter(R_args=R_args, maxiter=maxiter)
+        R_args <- frm_define_model_R_function_include_maxiter(R_args=R_args,
+                            maxiter=maxiter)
     }
     #--- linear regression with Box-Cox Transformation
     if (model$model %in% c("bctreg") ){
@@ -54,7 +56,8 @@ frm_define_model_R_function <- function(model, use_grad=2, use_gibbs=FALSE,
         R_args$use_grad <- use_grad
         R_density_fct <- "frm_mdmb_regression_density"
         R_args$probit <- NULL
-        R_args <- frm_define_model_R_function_include_maxiter(R_args=R_args, maxiter=maxiter)
+        R_args <- frm_define_model_R_function_include_maxiter(R_args=R_args,
+                            maxiter=maxiter)
     }
     #--- linear regression with Yeo-Johnson Transformation
     if (model$model %in% c("yjtreg") ){
@@ -62,7 +65,8 @@ frm_define_model_R_function <- function(model, use_grad=2, use_gibbs=FALSE,
         R_fct_name <- "mdmb::yjt_regression"
         R_args$use_grad <- use_grad
         R_density_fct <- "frm_mdmb_regression_density"
-        R_args <- frm_define_model_R_function_include_maxiter(R_args=R_args, maxiter=maxiter)
+        R_args <- frm_define_model_R_function_include_maxiter(R_args=R_args,
+                            maxiter=maxiter)
         if (is.null(R_args$probit)){
             R_args$probit <- FALSE
         }
@@ -94,8 +98,9 @@ frm_define_model_R_function <- function(model, use_grad=2, use_gibbs=FALSE,
         }
     }
     #--- output
-    res <- list( R_fct=R_fct, R_args=R_args, R_density_fct=R_density_fct, R_fct_name=R_fct_name,
-                    use_gibbs_model=use_gibbs_model, R_sampling_fct=R_sampling_fct,
-                    sampling_level=sampling_level, variable_level=variable_level)
+    res <- list( R_fct=R_fct, R_args=R_args, R_density_fct=R_density_fct,
+                    R_fct_name=R_fct_name, use_gibbs_model=use_gibbs_model,
+                    R_sampling_fct=R_sampling_fct, sampling_level=sampling_level,
+                    variable_level=variable_level)
     return(res)
 }
