@@ -1,5 +1,5 @@
 ## File Name: frm_fb_initial_parameters.R
-## File Version: 0.475
+## File Version: 0.478
 
 frm_fb_initial_parameters <- function(dat, ind0, data_init, ind_miss=NULL )
 {
@@ -54,7 +54,8 @@ frm_fb_initial_parameters <- function(dat, ind0, data_init, ind_miss=NULL )
         ind_mm$variable_info <- variable_info
 
         #*** estimate model
-        R_args <- frm_estimate_model_create_R_args(dat=dat, weights=weights, ind_mm=ind_mm)
+        R_args <- frm_estimate_model_create_R_args(dat=dat, weights=weights,
+                            ind_mm=ind_mm)
         mod_weights <- R_args$weights
         n_data <- nrow(R_args$data)
         R_args <- frm_append_list(list1=R_args, list2=ind_mm$R_args)
@@ -105,7 +106,8 @@ frm_fb_initial_parameters <- function(dat, ind0, data_init, ind_miss=NULL )
         }
         if ( est_sigma ){
             mod_resid <- residuals(mod)
-            sigma <- mdmb_weighted_sd(x=mod_resid, w=mod_weights, unbiased=TRUE, na.rm=TRUE)
+            sigma <- mdmb_weighted_sd(x=mod_resid, w=mod_weights,
+                                unbiased=TRUE, na.rm=TRUE)
             ind_mm$N_sigma <- 1
             ind_mm$sample_sigma <- TRUE
             ind_mm$sigma <- sigma
