@@ -1,8 +1,9 @@
 ## File Name: frm_mlreg_density.R
-## File Version: 0.167
+## File Version: 0.170
 
 
-frm_mlreg_density <- function( model, y, case, design_matrix, id_variable_level_unique=NULL)
+frm_mlreg_density <- function( model, y, case, design_matrix,
+                        id_variable_level_unique=NULL)
 {
     outcome <- model$outcome
     data <- design_matrix
@@ -24,8 +25,9 @@ frm_mlreg_density <- function( model, y, case, design_matrix, id_variable_level_
     outcome <- model$outcome
     K <- model$K
     #- evaluate densities
-    ypred <- miceadds::miceadds_rcpp_ml_mcmc_predict_fixed_random( X=X, beta=beta, Z_list=Z_list,
-                        u_list=u_list, idcluster_list=idcluster_list, NR=NR )
+    ypred <- miceadds::miceadds_rcpp_ml_mcmc_predict_fixed_random( X=X, beta=beta,
+                            Z_list=Z_list, u_list=u_list, idcluster_list=idcluster_list,
+                            NR=NR )
     ypred <- ypred[,1]
     if (outcome=="normal"){
         sigma <- sqrt(sigma2)
