@@ -1,7 +1,7 @@
 ## File Name: frm_prepare_data_em.R
-## File Version: 0.28
+## File Version: 0.295
 
-frm_prepare_data_em <- function(dat, dep, ind, weights0, dat0)
+frm_prepare_data_em <- function(dat, dep, ind, weights0, dat0, update_model=NULL)
 {
     NM <- attr(ind,"NM")
     N <- nrow(dat)
@@ -17,14 +17,17 @@ frm_prepare_data_em <- function(dat, dep, ind, weights0, dat0)
         var_mm <- ind_mm$dv_vars
         dv_vars <- c( dv_vars, var_mm)
         nodes_mm <- ind_mm$nodes
-        dat <- frm_prepare_data_include_latent_data( dat=dat, var_mm=var_mm, nodes_mm=nodes_mm,
-                    ind_mm=ind[[mm]] )
+        dat <- frm_prepare_data_include_latent_data( dat=dat, var_mm=var_mm,
+                        nodes_mm=nodes_mm, ind_mm=ind[[mm]] )
     }
     #** prepare dependent variables
     dat <- frm_prepare_data_include_latent_data( dat=dat,
                     var_mm=dep$dv_vars, nodes_mm=dep$nodes, ind_mm=dep )
     dv_vars <- c( dv_vars, dep$dv_vars )
     dat$weights <- dat$weights * dat$weights0
+    if ( ! is.null(update_model) ){
+        dat <- update_model$dat
+    }
     # extract matrix with response indicators
     dat_resp <- dat[, paste0( "resp_", dv_vars ) ]
     ind_miss <- ind_resp <- list()
